Module evdev

Module evdev 

Modules

event_variants
The event_variants module contains new-type wrappers around InputEvent for each known EventType.
raw_stream
A device implementation with no userspace synchronization performed.
uinput
Virtual device emulation for evdev via uinput.

Structs

AbsInfo
A wrapped input_absinfo returned by EVIOCGABS and used with uinput to set up absolute axes
AbsoluteAxisCode
A type of absolute axis measurement, typically used for touch events and joysticks.
AbsoluteAxisEvent
EventType::ABSOLUTE
AttributeSet
AttributeSetRef
A collection of bits representing either device capability or state.
AutoRepeat
Auto-repeat settings for a device.
BusType
The bus type of an InputId.
Device
A physical or virtual device supported by evdev.
DeviceState
A cached representation of device state at a certain time.
EnumParseError
An error type for the FromStr implementation for enum-like types in this crate.
EnumerateDevices
Event-device paths discovered without requiring read access to the nodes.
EventType
Event types supported by the device.
FFCondition
Describes a spring or friction force feedback effect.
FFEffect
Represents a force feedback effect that has been successfully uploaded to the device for playback.
FFEffectCode
Force feedback effect types
FFEffectData
FFEnvelope
Describes a generic force feedback effect envelope.
FFEvent
EventType::FORCEFEEDBACK
FFReplay
Scheduling information for the force feedback effect.
FFStatusCode
Force feedback effect status
FFStatusEvent
EventType::FORCEFEEDBACKSTATUS
FFTrigger
Trigger information for the force feedback effect.
FetchEventsSynced
An iterator over events of a Device, produced by Device::fetch_events.
InputEvent
A wrapped input_event returned by the input device via the kernel.
InputId
KeyCode
Scancodes for key presses.
KeyEvent
EventType::KEY
LedCode
LEDs specified by USB HID.
LedEvent
EventType::LED
MiscCode
Various miscellaneous event types.
MiscEvent
EventType::MISC
OtherCode
OtherEvent
An event not covered by any other variant.
PowerCode
PowerEvent
EventType::POWER
PropType
Device properties.
RelativeAxisCode
A type of relative axis measurement, typically produced by mice.
RelativeAxisEvent
EventType::RELATIVE
RepeatCode
RepeatEvent
EventType::REPEAT
SoundCode
A type associated with simple sounds, such as beeps or tones.
SoundEvent
EventType::SOUND
SwitchCode
An event type corresponding to a physical or virtual switch.
SwitchEvent
EventType::SWITCH
SynchronizationCode
A “synchronization” message type published by the kernel into the events stream.
SynchronizationEvent
A bookkeeping event. Usually not important to applications. EventType::SYNCHRONIZATION
UInputCode
A uinput event published by the kernel into the events stream for uinput devices.
UInputEvent
EventType::UINPUT
UinputAbsSetup
A wrapped uinput_abs_setup, used to set up analogue axes with uinput

Enums

EventSummary
A convenience mapping for matching a InputEvent while simultaniously checking its kind (type, code) and capturing the value
FFEffectKind
FFWaveform
Describes the waveform for periodic force feedback effects.

Traits

EvdevEnum

Functions

enumerate
Crawls /dev/input for event-device paths without opening device nodes.