enumerate

Function enumerate 

pub fn enumerate() -> EnumerateDevices 
Crawls /dev/input for evdev devices.

Will not bubble up any errors in opening devices or traversing the directory. Instead returns an empty iterator or omits the devices that could not be opened.