PropType

Struct PropType 

pub struct PropType(pub u16);
Device properties.

Tuple Fields

0: u16

Implementations

Source

impl PropType

pub const POINTER: PropType

This input device needs a pointer (“cursor”) for the user to know its state.

pub const DIRECT: PropType

“direct input devices”, according to the header.

pub const BUTTONPAD: PropType

“has button(s) under pad”, according to the header.

pub const SEMI_MT: PropType

Touch rectangle only (I think this means that if there are multiple touches, then the bounding rectangle of all the touches is returned, not each touch).

pub const TOPBUTTONPAD: PropType

“softbuttons at top of pad”, according to the header.

pub const POINTING_STICK: PropType

Is a pointing stick (“nub” etc, https://xkcd.com/243/)

pub const ACCELEROMETER: PropType

Has an accelerometer. Probably reports relative events in that case?