Virtual device emulation for evdev via uinput.
This is quite useful when testing/debugging devices, or synchronization.
Structs
- DevNodes
Blocking - This struct is returned from the VirtualDevice::enumerate_dev_nodes_blocking function and will yield
the syspaths corresponding to the virtual device. These are of the form
/dev/input123. - FFErase
Event - Represents a force feedback erase event that we are currently processing.
- FFUpload
Event - Represents a force feedback upload event that we are currently processing.
- Virtual
Device - A handle to a uinput virtual device.
- Virtual
Device Builder - A builder struct for creating a new uinput virtual device.