VirtualDevice

Struct VirtualDevice 

pub struct VirtualDevice { /* private fields */ }
A handle to a uinput virtual device.

Implementations

Source

impl VirtualDevice

pub fn builder<'a>() -> Result<VirtualDeviceBuilder<'a>, Error>

Convenience method for creating a VirtualDeviceBuilder.

pub fn get_syspath(&mut self) -> Result<PathBuf, Error>

Get the syspath representing this uinput device.

The syspath returned is the one of the input node itself (e.g. /sys/devices/virtual/input/input123), not the syspath of the device node.

pub fn enumerate_dev_nodes_blocking( &mut self, ) -> Result<DevNodesBlocking, Error>

Get the syspaths of the corresponding device nodes in /dev/input.

pub fn emit(&mut self, events: &[InputEvent]) -> Result<(), Error>

Post a batch of events to the virtual device.

The batch is automatically terminated with a SYN_REPORT event. Events from physical devices are batched based on if they occur simultaneously, for example movement of a mouse triggers a movement events for the X and Y axes separately in a batch of 2 events.

Single events such as a KEY event must still be followed by a SYN_REPORT.

pub fn process_ff_upload( &mut self, event: UInputEvent, ) -> Result<FFUploadEvent, Error>

Processes the given UInputEvent if it is a force feedback upload event, in which case this function will start the force feedback upload and claim ownership over the UInputEvent and return a FFUploadEvent instead.

The returned event allows the user to allocate and set the effect ID as well as access the effect data.

Panics

This function will panic if event.code() is not UI_FF_UPLOAD.

pub fn process_ff_erase( &mut self, event: UInputEvent, ) -> Result<FFEraseEvent, Error>

Processes the given UInputEvent if it is a force feedback erase event, in which case this function will start the force feedback erasure and claim ownership over the UInputEvent and return a FFEraseEvent instead.

The returned event allows the user to access the effect ID, such that it can free any memory used for the given effect ID.

Panics

This function will panic if event.code() is not UI_FF_ERASE.

pub fn fetch_events( &mut self, ) -> Result<impl Iterator<Item = InputEvent>, Error>

Fetches and returns events from the kernel ring buffer without doing synchronization on SYN_DROPPED.

By default this will block until events are available. Typically, users will want to call this in a tight loop within a thread.