pub struct VirtualDeviceBuilder<'a> { /* private fields */ }Expand description
A builder struct for creating a new uinput virtual device.
Implementations
Sourceimpl<'a> VirtualDeviceBuilder<'a>
A builder struct for VirtualDevice.
impl<'a> VirtualDeviceBuilder<'a>
A builder struct for VirtualDevice.
Created via VirtualDevice::builder().
Sourcepub fn name<S>(self, name: &'a S) -> VirtualDeviceBuilder<'a>
pub fn name<S>(self, name: &'a S) -> VirtualDeviceBuilder<'a>
Set the display name of this device.
Sourcepub fn input_id(self, id: InputId) -> VirtualDeviceBuilder<'a>
pub fn input_id(self, id: InputId) -> VirtualDeviceBuilder<'a>
Set a custom input ID.
Sourcepub fn with_phys(self, path: &CStr) -> Result<VirtualDeviceBuilder<'a>, Error>
pub fn with_phys(self, path: &CStr) -> Result<VirtualDeviceBuilder<'a>, Error>
Set the device’s physical location, e.g. usb-00:01.2-2.1/input0.
Sourcepub fn with_keys(
self,
keys: &AttributeSetRef<KeyCode>,
) -> Result<VirtualDeviceBuilder<'a>, Error>
pub fn with_keys( self, keys: &AttributeSetRef<KeyCode>, ) -> Result<VirtualDeviceBuilder<'a>, Error>
Set the key codes that can be emitted by this device.
Sourcepub fn with_absolute_axis(
self,
axis: &UinputAbsSetup,
) -> Result<VirtualDeviceBuilder<'a>, Error>
pub fn with_absolute_axis( self, axis: &UinputAbsSetup, ) -> Result<VirtualDeviceBuilder<'a>, Error>
Set the absolute axes of this device.
Sourcepub fn with_relative_axes(
self,
axes: &AttributeSetRef<RelativeAxisCode>,
) -> Result<VirtualDeviceBuilder<'a>, Error>
pub fn with_relative_axes( self, axes: &AttributeSetRef<RelativeAxisCode>, ) -> Result<VirtualDeviceBuilder<'a>, Error>
Set the relative axes of this device.
Sourcepub fn with_properties(
self,
switches: &AttributeSetRef<PropType>,
) -> Result<VirtualDeviceBuilder<'a>, Error>
pub fn with_properties( self, switches: &AttributeSetRef<PropType>, ) -> Result<VirtualDeviceBuilder<'a>, Error>
Set the properties of this device.
Sourcepub fn with_switches(
self,
switches: &AttributeSetRef<SwitchCode>,
) -> Result<VirtualDeviceBuilder<'a>, Error>
pub fn with_switches( self, switches: &AttributeSetRef<SwitchCode>, ) -> Result<VirtualDeviceBuilder<'a>, Error>
Set the switch codes that can be emitted by this device.
Sourcepub fn with_ff(
self,
ff: &AttributeSetRef<FFEffectCode>,
) -> Result<VirtualDeviceBuilder<'a>, Error>
pub fn with_ff( self, ff: &AttributeSetRef<FFEffectCode>, ) -> Result<VirtualDeviceBuilder<'a>, Error>
Set the force-feedback effects that can be emitted by this device.
Sourcepub fn with_ff_effects_max(
self,
ff_effects_max: u32,
) -> VirtualDeviceBuilder<'a>
pub fn with_ff_effects_max( self, ff_effects_max: u32, ) -> VirtualDeviceBuilder<'a>
Set the maximum number for a force-feedback effect for this device.
Sourcepub fn with_msc(
self,
misc_set: &AttributeSetRef<MiscCode>,
) -> Result<VirtualDeviceBuilder<'a>, Error>
pub fn with_msc( self, misc_set: &AttributeSetRef<MiscCode>, ) -> Result<VirtualDeviceBuilder<'a>, Error>
Set the MiscCodes of this device.