pub struct TabletPadDialEvent { /* private fields */ }Expand description
A status change on a dial on a device with the DeviceCapability::TabletPad
capability.
Implementations
Sourceimpl TabletPadDialEvent
impl TabletPadDialEvent
Sourcepub fn dial_v120(&self) -> f64
pub fn dial_v120(&self) -> f64
Returns the delta change of the dial, in multiples or fractions of 120, with each multiple of 120 indicating one logical wheel event.
See PointerScrollWheelEvent::scroll_value_v120
for more details.