Solidity compiler bindings for Rust.
This crate provides types and builders for interacting with the Solidity compiler’s Standard JSON interface.
Re-exports
pub use input::StandardJsonInput;
Solidity compiler bindings for Rust.
This crate provides types and builders for interacting with the Solidity compiler’s Standard JSON interface.
pub use input::StandardJsonInput;