Modules
- event_
variants - The event_variants module contains new-type wrappers around
InputEventfor each knownEventType. - raw_
stream - A device implementation with no userspace synchronization performed.
- uinput
- Virtual device emulation for evdev via uinput.
Structs
- AbsInfo
- A wrapped
input_absinforeturned by EVIOCGABS and used with uinput to set up absolute axes - Absolute
Axis Code - A type of absolute axis measurement, typically used for touch events and joysticks.
- Absolute
Axis Event EventType::ABSOLUTE- Attribute
Set - Attribute
SetRef - A collection of bits representing either device capability or state.
- Auto
Repeat - Auto-repeat settings for a device.
- BusType
- The bus type of an
InputId. - Device
- A physical or virtual device supported by evdev.
- Device
State - A cached representation of device state at a certain time.
- Enum
Parse Error - An error type for the
FromStrimplementation for enum-like types in this crate. - Enumerate
Devices - Event-device paths discovered without requiring read access to the nodes.
- Event
Type - Event types supported by the device.
- FFCondition
- Describes a spring or friction force feedback effect.
- FFEffect
- Represents a force feedback effect that has been successfully uploaded to the device for playback.
- FFEffect
Code - Force feedback effect types
- FFEffect
Data - FFEnvelope
- Describes a generic force feedback effect envelope.
- FFEvent
EventType::FORCEFEEDBACK- FFReplay
- Scheduling information for the force feedback effect.
- FFStatus
Code - Force feedback effect status
- FFStatus
Event EventType::FORCEFEEDBACKSTATUS- FFTrigger
- Trigger information for the force feedback effect.
- Fetch
Events Synced - An iterator over events of a
Device, produced byDevice::fetch_events. - Input
Event - A wrapped
input_eventreturned by the input device via the kernel. - InputId
- KeyCode
- Scancodes for key presses.
- KeyEvent
EventType::KEY- LedCode
- LEDs specified by USB HID.
- LedEvent
EventType::LED- Misc
Code - Various miscellaneous event types.
- Misc
Event EventType::MISC- Other
Code - Other
Event - An event not covered by any other variant.
- Power
Code - Power
Event EventType::POWER- Prop
Type - Device properties.
- Relative
Axis Code - A type of relative axis measurement, typically produced by mice.
- Relative
Axis Event EventType::RELATIVE- Repeat
Code - Repeat
Event EventType::REPEAT- Sound
Code - A type associated with simple sounds, such as beeps or tones.
- Sound
Event EventType::SOUND- Switch
Code - An event type corresponding to a physical or virtual switch.
- Switch
Event EventType::SWITCH- Synchronization
Code - A “synchronization” message type published by the kernel into the events stream.
- Synchronization
Event - A bookkeeping event. Usually not important to applications.
EventType::SYNCHRONIZATION - UInput
Code - A uinput event published by the kernel into the events stream for uinput devices.
- UInput
Event EventType::UINPUT- Uinput
AbsSetup - A wrapped
uinput_abs_setup, used to set up analogue axes with uinput
Enums
- Event
Summary - A convenience mapping for matching a
InputEventwhile simultaniously checking its kind(type, code)and capturing the value - FFEffect
Kind - FFWaveform
- Describes the waveform for periodic force feedback effects.
Traits
Functions
- enumerate
- Crawls
/dev/inputfor event-device paths without opening device nodes.